pre_processing
--------------

Pre-processing modules take care of ensuring all data are processed the same. Note that gaps should
be padded after filtering if you decide not to use these routines (see notes in correlation_warnings_).

.. _correlation_warnings: utils.correlate.html#notes-on-accuracy

.. currentmodule:: eqcorrscan.utils.pre_processing
.. automodule:: eqcorrscan.utils.pre_processing

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       dayproc
       process
       shortproc

    .. comment to end block
